# `aiida-pseudo`

AiiDA plugin that simplifies working with pseudo potentials.

[![PyPI version](https://badge.fury.io/py/aiida-pseudo.svg)](https://badge.fury.io/py/aiida-pseudo)
[![PyPI pyversions](https://img.shields.io/pypi/pyversions/aiida-pseudo.svg)](https://pypi.python.org/pypi/aiida-pseudo/)
[![Build Status](https://github.com/aiidateam/aiida-pseudo/workflows/continuous-integration/badge.svg?event=push)](https://github.com/aiidateam/aiida-pseudo/actions)
[![Docs status](https://readthedocs.org/projects/aiida-pseudo/badge)](http://aiida-pseudo.readthedocs.io/)
